package com.hongyegroup.cpt_ewallet.ui

import android.content.Intent
import android.os.Bundle
import androidx.databinding.DataBindingUtil
import com.chad.library.adapter.base.listener.OnLoadMoreListener
import com.guadou.cs_cptservices.base.activity.YYBaseVDBActivity
import com.guadou.cs_cptservices.popup.CustomNormalPopup
import com.guadou.lib_baselib.bean.DataBindingConfig
import com.guadou.lib_baselib.engine.toast
import com.guadou.lib_baselib.ext.vertical
import com.guadou.lib_baselib.utils.CommUtils
import com.hongyegroup.cpt_ewallet.BR
import com.hongyegroup.cpt_ewallet.R
import com.hongyegroup.cpt_ewallet.bean.BankCardBean
import com.hongyegroup.cpt_ewallet.databinding.ActivityEwalletSalarycardBinding
import com.hongyegroup.cpt_ewallet.databinding.ItemSalaryBankCardHeaderBinding
import com.hongyegroup.cpt_ewallet.mvvm.EWalletSalaryCardViewModel
import com.lxj.xpopup.XPopup
import com.scwang.smart.refresh.layout.api.RefreshLayout
import com.scwang.smart.refresh.layout.listener.OnRefreshListener
import dagger.hilt.android.AndroidEntryPoint

/**
 * 电子钱包工资卡列表
 */
@AndroidEntryPoint
class EWalletSalaryCardActivity : YYBaseVDBActivity<EWalletSalaryCardViewModel, ActivityEwalletSalarycardBinding>(), OnRefreshListener,
    OnLoadMoreListener {

    companion object {
        fun startInstance() {
            val context = CommUtils.getContext()
            val intent = Intent(context, EWalletSalaryCardActivity::class.java)
            intent.addFlags(Intent.FLAG_ACTIVITY_NEW_TASK)
            context.startActivity(intent)
        }
    }

    override fun getDataBindingConfig(): DataBindingConfig {
        return DataBindingConfig(R.layout.activity_ewallet_salarycard)
    }

    override fun init(savedInstanceState: Bundle?) {
        setStatusBarBlackText()

        initRV()
        initData()
        initListener()
    }

    private fun initData() {
        mViewModel.getAllBankCards().observe(this) {
            mBinding.refreshLayout.finishRefresh()
            mViewModel.mAdapter.loadMoreModule.isEnableLoadMore = true
        }
    }

    private fun initRV() {
        //获取到头部局
        val headerView = CommUtils.inflate(R.layout.item_salary_bank_card_header)
        //绑定DataBinding 并赋值自定义的数据
        DataBindingUtil.bind<ItemSalaryBankCardHeaderBinding>(headerView)?.apply {
            setVariable(BR.click, ClickProxy())
        }
        mViewModel.mAdapter.addHeaderView(headerView)

        mBinding.recyclerView.vertical().adapter = mViewModel.mAdapter
    }

    private fun initListener() {
        //Adapter的滑动监听，监听加载更多
        mViewModel.mAdapter.loadMoreModule.isEnableLoadMore = false
        mViewModel.mAdapter.loadMoreModule.preLoadNumber = 4
        mViewModel.mAdapter.loadMoreModule.setOnLoadMoreListener(this)

        //刷新控件初始化
        mBinding.refreshLayout.setEnableNestedScroll(true)
        mBinding.refreshLayout.setEnableLoadMore(false)
        mBinding.refreshLayout.setEnableRefresh(true)
        mBinding.refreshLayout.setOnRefreshListener(this)

        //Item点击
        mViewModel.mAdapter.addChildClickViewIds(R.id.ll_content_root, R.id.tv_bank_unbind)
        mViewModel.mAdapter.setOnItemChildClickListener { _, view, position ->
            val item = mViewModel.mDatas[position]
            when (view.id) {
                R.id.tv_bank_unbind -> {
                    unbindCardPopup(item)
                }
                else -> {
                    toast("进入我的银行卡:$position")
                }
            }

        }
    }

    //解绑银行卡弹窗
    private fun unbindCardPopup(cardBean: BankCardBean) {
        XPopup.Builder(mActivity)
            .asCustom(
                CustomNormalPopup(mActivity, null, "确认解绑银行卡？", "确认解绑", "放弃解绑") {
                    toast("执行解绑操作")
                }
            )
            .show()
    }

    override fun onRefresh(refreshLayout: RefreshLayout) {
        mViewModel.isNeedCleanAllData = true
        mViewModel.mAdapter.loadMoreModule.loadMoreComplete()
        mViewModel.mAdapter.loadMoreModule.isEnableLoadMore = false
        //直接调用，参数从成员变量中获取
        mViewModel.mCurPage = 1
        initData()
    }

    override fun onLoadMore() {
        mViewModel.isNeedCleanAllData = false
        mViewModel.mCurPage++
        initData()
    }

    override fun startObserve() {

    }

    /**
     * DataBinding事件处理
     */
    inner class ClickProxy {

        //添加新的银行卡
        fun addBankCard() {
            SalaryCardAddStepOneActivity.startInstance()
        }
    }
}