package com.hongyegroup.cpt_ewallet.ui

import android.content.Intent
import android.os.Bundle
import android.text.Html
import com.guadou.cs_cptservices.base.activity.YYBaseVDBActivity
import com.guadou.lib_baselib.bean.DataBindingConfig
import com.guadou.lib_baselib.engine.toast
import com.guadou.lib_baselib.utils.CommUtils
import com.guadou.lib_baselib.utils.KeyboardUtils
import com.hongyegroup.cpt_ewallet.BR
import com.hongyegroup.cpt_ewallet.R
import com.hongyegroup.cpt_ewallet.databinding.ActivityEwalletWithdrawalBinding
import com.hongyegroup.cpt_ewallet.mvvm.EWalletWithdrawalViewModel
import com.hongyegroup.cpt_ewallet.widget.ChooseBankCardPopup
import com.lxj.xpopup.XPopup
import dagger.hilt.android.AndroidEntryPoint

@AndroidEntryPoint
class EWalletWithdrawalActivity : YYBaseVDBActivity<EWalletWithdrawalViewModel, ActivityEwalletWithdrawalBinding>() {

    companion object {
        fun startInstance() {
            val context = CommUtils.getContext()
            val intent = Intent(context, EWalletWithdrawalActivity::class.java)
            intent.addFlags(Intent.FLAG_ACTIVITY_NEW_TASK)
            context.startActivity(intent)
        }
    }

    override fun getDataBindingConfig(): DataBindingConfig {
        return DataBindingConfig(R.layout.activity_ewallet_withdrawal, BR.viewModel, mViewModel)
            .addBindingParams(BR.click, ClickProxy())
    }

    override fun init(savedInstanceState: Bundle?) {
        setStatusBarBlackText()

        initData()

    }

    private fun initData() {
        mBinding.tvMoneyAvailable.text = Html.fromHtml(getString(R.string.ewallet_balance_available, "980.5"))
    }

    override fun startObserve() {

    }

    /**
     * DataBinding事件处理
     */
    inner class ClickProxy {

        //选择银行卡
        fun selectBankCard() {
            KeyboardUtils.hideSoftInput(mActivity)
            chooseBankCard()
        }

        //选择银行卡Popup
        private fun chooseBankCard() {
            XPopup.Builder(mActivity)
                .moveUpToKeyboard(false)
                .hasShadowBg(true)
                .asCustom(ChooseBankCardPopup(mActivity,
                    addNewCardAction = {
                        //去添加新的银行卡
                        SalaryCardAddStepOneActivity.startInstance()
                    }, chooseCardAction = { pos ->
                        toast("选择了第 $pos 个索引")
                    })
                )
                .show()
        }

        //去下一步
        fun gotoNext() {
            KeyboardUtils.hideSoftInput(mActivity)
            WithdrawalVerifyActivity.startInstance()
        }

    }
}